=======================
|project| Documentation
=======================

A flight software and embedded systems framework. This is the automatically generated API
documentation for the `fprime` python package. This package contains the necessary types and setup
to write support code for F´ including both Autocoder functions and Ground Data System packages.

This package also provides the `fprime-util` command line utility used to help build F´ following
the recommended development process. This tool simplifies the CMake setup for general use cases
while allowing for CMake to support advanced features.

Table of Contents
=================

.. toctree::
   :maxdepth: 2

   API <api/index.rst>


Indices
=======

* :ref:`modindex`
* :ref:`genindex`
* :ref:`search`
